@@ -34,8 +34,6 @@ debug_xy = 0
 #Consts
 speed=.25          #Speed can be float and move will occur in integers
 level_speed = speed
-speed_bumpx = .25
-speed_bumpy = .25
 smooth=20       #Rate of change in accelerometer before a speed/direction change is registered
 accel_div=12
 max_accel=25
